.text-no-select{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.trame__loader{display:block;position:relative;left:50%;top:calc(50% - 50px);width:150px;height:150px;margin:-75px 0 0 -75px;border-radius:50%;border:10px solid transparent;border-top-color:#ac262c;-webkit-animation:spin 2s linear infinite;animation:spin 2s linear infinite}.trame__loader:before{content:"";position:absolute;top:5px;left:5px;right:5px;bottom:5px;border-radius:50%;border:10px solid transparent;border-top-color:#258e44;-webkit-animation:spin 3s linear infinite;animation:spin 3s linear infinite}.trame__loader:after{content:"";position:absolute;top:20px;left:20px;right:20px;bottom:20px;border-radius:50%;border:10px solid transparent;border-top-color:#1c4678;-webkit-animation:spin 1.5s linear infinite;animation:spin 1.5s linear infinite}.trame__message{position:absolute;text-align:center;width:100%;top:calc(50% + 50px);font-size:200%;user-select:none}@-webkit-keyframes spin{0%{-webkit-transform:rotate(0deg);-ms-transform:rotate(0deg);transform:rotate(0)}to{-webkit-transform:rotate(360deg);-ms-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes spin{0%{-webkit-transform:rotate(0deg);-ms-transform:rotate(0deg);transform:rotate(0)}to{-webkit-transform:rotate(360deg);-ms-transform:rotate(360deg);transform:rotate(360deg)}}
